@@ -4,11 +4,17 @@ package Grizzly::Progress::Bar;
 
 use strict;
 use warnings;
+use parent qw(Exporter);
 
 use Term::Clear ();
 use Term::ProgressBar 2.00;
 use constant MAX => 100_000;
 
+require Exporter;
+our @ISA = ("Exporter");
+
+our @EXPORT = qw(progressbar);
+
 sub progressbar {
     my ($self) = @_;
 
@@ -47,7 +53,7 @@ Grizzly::Progress::Bar - Runs a progress bar when called
 
 =head1 VERSION
 
-version 0.104
+version 0.110
 
 =head1 DESCRIPTION
 
